# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AuthBackendArgs', 'AuthBackend']

@pulumi.input_type
class AuthBackendArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 tune: Optional[pulumi.Input['AuthBackendTuneArgs']] = None):
        """
        The set of arguments for constructing a AuthBackend resource.
        :param pulumi.Input[str] type: The name of the auth method type.
        :param pulumi.Input[str] description: A description of the auth method.
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: The path to mount the auth method — this defaults to the name of the type.
        :param pulumi.Input['AuthBackendTuneArgs'] tune: Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        """
        pulumi.set(__self__, "type", type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_remount is not None:
            pulumi.set(__self__, "disable_remount", disable_remount)
        if local is not None:
            pulumi.set(__self__, "local", local)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if tune is not None:
            pulumi.set(__self__, "tune", tune)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The name of the auth method type.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A description of the auth method.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableRemount")
    def disable_remount(self) -> Optional[pulumi.Input[bool]]:
        """
        If set, opts out of mount migration on path updates.
        See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        """
        return pulumi.get(self, "disable_remount")

    @disable_remount.setter
    def disable_remount(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_remount", value)

    @property
    @pulumi.getter
    def local(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies if the auth method is local only.
        """
        return pulumi.get(self, "local")

    @local.setter
    def local(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "local", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The path to mount the auth method — this defaults to the name of the type.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def tune(self) -> Optional[pulumi.Input['AuthBackendTuneArgs']]:
        """
        Extra configuration block. Structure is documented below.

        The `tune` block is used to tune the auth backend:
        """
        return pulumi.get(self, "tune")

    @tune.setter
    def tune(self, value: Optional[pulumi.Input['AuthBackendTuneArgs']]):
        pulumi.set(self, "tune", value)


@pulumi.input_type
class _AuthBackendState:
    def __init__(__self__, *,
                 accessor: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 tune: Optional[pulumi.Input['AuthBackendTuneArgs']] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AuthBackend resources.
        :param pulumi.Input[str] accessor: The accessor for this auth method
        :param pulumi.Input[str] description: A description of the auth method.
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: The path to mount the auth method — this defaults to the name of the type.
        :param pulumi.Input['AuthBackendTuneArgs'] tune: Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        :param pulumi.Input[str] type: The name of the auth method type.
        """
        if accessor is not None:
            pulumi.set(__self__, "accessor", accessor)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_remount is not None:
            pulumi.set(__self__, "disable_remount", disable_remount)
        if local is not None:
            pulumi.set(__self__, "local", local)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if tune is not None:
            pulumi.set(__self__, "tune", tune)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def accessor(self) -> Optional[pulumi.Input[str]]:
        """
        The accessor for this auth method
        """
        return pulumi.get(self, "accessor")

    @accessor.setter
    def accessor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accessor", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A description of the auth method.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableRemount")
    def disable_remount(self) -> Optional[pulumi.Input[bool]]:
        """
        If set, opts out of mount migration on path updates.
        See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        """
        return pulumi.get(self, "disable_remount")

    @disable_remount.setter
    def disable_remount(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_remount", value)

    @property
    @pulumi.getter
    def local(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies if the auth method is local only.
        """
        return pulumi.get(self, "local")

    @local.setter
    def local(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "local", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The path to mount the auth method — this defaults to the name of the type.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def tune(self) -> Optional[pulumi.Input['AuthBackendTuneArgs']]:
        """
        Extra configuration block. Structure is documented below.

        The `tune` block is used to tune the auth backend:
        """
        return pulumi.get(self, "tune")

    @tune.setter
    def tune(self, value: Optional[pulumi.Input['AuthBackendTuneArgs']]):
        pulumi.set(self, "tune", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the auth method type.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class AuthBackend(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 tune: Optional[pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        Auth methods can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:index/authBackend:AuthBackend example github
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A description of the auth method.
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: The path to mount the auth method — this defaults to the name of the type.
        :param pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']] tune: Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        :param pulumi.Input[str] type: The name of the auth method type.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuthBackendArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Auth methods can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:index/authBackend:AuthBackend example github
        ```

        :param str resource_name: The name of the resource.
        :param AuthBackendArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthBackendArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 tune: Optional[pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthBackendArgs.__new__(AuthBackendArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["disable_remount"] = disable_remount
            __props__.__dict__["local"] = local
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["path"] = path
            __props__.__dict__["tune"] = tune
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["accessor"] = None
        super(AuthBackend, __self__).__init__(
            'vault:index/authBackend:AuthBackend',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accessor: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            disable_remount: Optional[pulumi.Input[bool]] = None,
            local: Optional[pulumi.Input[bool]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            path: Optional[pulumi.Input[str]] = None,
            tune: Optional[pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'AuthBackend':
        """
        Get an existing AuthBackend resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accessor: The accessor for this auth method
        :param pulumi.Input[str] description: A description of the auth method.
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: The path to mount the auth method — this defaults to the name of the type.
        :param pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']] tune: Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        :param pulumi.Input[str] type: The name of the auth method type.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthBackendState.__new__(_AuthBackendState)

        __props__.__dict__["accessor"] = accessor
        __props__.__dict__["description"] = description
        __props__.__dict__["disable_remount"] = disable_remount
        __props__.__dict__["local"] = local
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["path"] = path
        __props__.__dict__["tune"] = tune
        __props__.__dict__["type"] = type
        return AuthBackend(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def accessor(self) -> pulumi.Output[str]:
        """
        The accessor for this auth method
        """
        return pulumi.get(self, "accessor")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A description of the auth method.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="disableRemount")
    def disable_remount(self) -> pulumi.Output[Optional[bool]]:
        """
        If set, opts out of mount migration on path updates.
        See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        """
        return pulumi.get(self, "disable_remount")

    @property
    @pulumi.getter
    def local(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies if the auth method is local only.
        """
        return pulumi.get(self, "local")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[str]:
        """
        The path to mount the auth method — this defaults to the name of the type.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def tune(self) -> pulumi.Output['outputs.AuthBackendTune']:
        """
        Extra configuration block. Structure is documented below.

        The `tune` block is used to tune the auth backend:
        """
        return pulumi.get(self, "tune")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The name of the auth method type.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetOidcClientCredsResult',
    'AwaitableGetOidcClientCredsResult',
    'get_oidc_client_creds',
    'get_oidc_client_creds_output',
]

@pulumi.output_type
class GetOidcClientCredsResult:
    """
    A collection of values returned by getOidcClientCreds.
    """
    def __init__(__self__, client_id=None, client_secret=None, id=None, name=None, namespace=None):
        if client_id and not isinstance(client_id, str):
            raise TypeError("Expected argument 'client_id' to be a str")
        pulumi.set(__self__, "client_id", client_id)
        if client_secret and not isinstance(client_secret, str):
            raise TypeError("Expected argument 'client_secret' to be a str")
        pulumi.set(__self__, "client_secret", client_secret)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> str:
        """
        The Client ID returned by Vault.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> str:
        """
        The Client Secret Key returned by Vault.
        For public OpenID Clients `client_secret` is set to an empty string `""`
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> Optional[str]:
        return pulumi.get(self, "namespace")


class AwaitableGetOidcClientCredsResult(GetOidcClientCredsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOidcClientCredsResult(
            client_id=self.client_id,
            client_secret=self.client_secret,
            id=self.id,
            name=self.name,
            namespace=self.namespace)


def get_oidc_client_creds(name: Optional[str] = None,
                          namespace: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOidcClientCredsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    app = vault.identity.OidcClient("app",
        redirect_uris=[
            "http://127.0.0.1:9200/v1/auth-methods/oidc:authenticate:callback",
            "http://127.0.0.1:8251/callback",
            "http://127.0.0.1:8080/callback",
        ],
        id_token_ttl=2400,
        access_token_ttl=7200)
    creds = vault.identity.get_oidc_client_creds_output(name=app.name)
    ```


    :param str name: The name of the OIDC Client in Vault.
    :param str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:identity/getOidcClientCreds:getOidcClientCreds', __args__, opts=opts, typ=GetOidcClientCredsResult).value

    return AwaitableGetOidcClientCredsResult(
        client_id=pulumi.get(__ret__, 'client_id'),
        client_secret=pulumi.get(__ret__, 'client_secret'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        namespace=pulumi.get(__ret__, 'namespace'))


@_utilities.lift_output_func(get_oidc_client_creds)
def get_oidc_client_creds_output(name: Optional[pulumi.Input[str]] = None,
                                 namespace: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOidcClientCredsResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    app = vault.identity.OidcClient("app",
        redirect_uris=[
            "http://127.0.0.1:9200/v1/auth-methods/oidc:authenticate:callback",
            "http://127.0.0.1:8251/callback",
            "http://127.0.0.1:8080/callback",
        ],
        id_token_ttl=2400,
        access_token_ttl=7200)
    creds = vault.identity.get_oidc_client_creds_output(name=app.name)
    ```


    :param str name: The name of the OIDC Client in Vault.
    :param str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
           *Available only for Vault Enterprise*.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, alias_canonical_id=None, alias_creation_time=None, alias_id=None, alias_last_update_time=None, alias_merged_from_canonical_ids=None, alias_metadata=None, alias_mount_accessor=None, alias_mount_path=None, alias_mount_type=None, alias_name=None, creation_time=None, data_json=None, group_id=None, group_name=None, id=None, last_update_time=None, member_entity_ids=None, member_group_ids=None, metadata=None, modify_index=None, namespace=None, namespace_id=None, parent_group_ids=None, policies=None, type=None):
        if alias_canonical_id and not isinstance(alias_canonical_id, str):
            raise TypeError("Expected argument 'alias_canonical_id' to be a str")
        pulumi.set(__self__, "alias_canonical_id", alias_canonical_id)
        if alias_creation_time and not isinstance(alias_creation_time, str):
            raise TypeError("Expected argument 'alias_creation_time' to be a str")
        pulumi.set(__self__, "alias_creation_time", alias_creation_time)
        if alias_id and not isinstance(alias_id, str):
            raise TypeError("Expected argument 'alias_id' to be a str")
        pulumi.set(__self__, "alias_id", alias_id)
        if alias_last_update_time and not isinstance(alias_last_update_time, str):
            raise TypeError("Expected argument 'alias_last_update_time' to be a str")
        pulumi.set(__self__, "alias_last_update_time", alias_last_update_time)
        if alias_merged_from_canonical_ids and not isinstance(alias_merged_from_canonical_ids, list):
            raise TypeError("Expected argument 'alias_merged_from_canonical_ids' to be a list")
        pulumi.set(__self__, "alias_merged_from_canonical_ids", alias_merged_from_canonical_ids)
        if alias_metadata and not isinstance(alias_metadata, dict):
            raise TypeError("Expected argument 'alias_metadata' to be a dict")
        pulumi.set(__self__, "alias_metadata", alias_metadata)
        if alias_mount_accessor and not isinstance(alias_mount_accessor, str):
            raise TypeError("Expected argument 'alias_mount_accessor' to be a str")
        pulumi.set(__self__, "alias_mount_accessor", alias_mount_accessor)
        if alias_mount_path and not isinstance(alias_mount_path, str):
            raise TypeError("Expected argument 'alias_mount_path' to be a str")
        pulumi.set(__self__, "alias_mount_path", alias_mount_path)
        if alias_mount_type and not isinstance(alias_mount_type, str):
            raise TypeError("Expected argument 'alias_mount_type' to be a str")
        pulumi.set(__self__, "alias_mount_type", alias_mount_type)
        if alias_name and not isinstance(alias_name, str):
            raise TypeError("Expected argument 'alias_name' to be a str")
        pulumi.set(__self__, "alias_name", alias_name)
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if data_json and not isinstance(data_json, str):
            raise TypeError("Expected argument 'data_json' to be a str")
        pulumi.set(__self__, "data_json", data_json)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if group_name and not isinstance(group_name, str):
            raise TypeError("Expected argument 'group_name' to be a str")
        pulumi.set(__self__, "group_name", group_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_update_time and not isinstance(last_update_time, str):
            raise TypeError("Expected argument 'last_update_time' to be a str")
        pulumi.set(__self__, "last_update_time", last_update_time)
        if member_entity_ids and not isinstance(member_entity_ids, list):
            raise TypeError("Expected argument 'member_entity_ids' to be a list")
        pulumi.set(__self__, "member_entity_ids", member_entity_ids)
        if member_group_ids and not isinstance(member_group_ids, list):
            raise TypeError("Expected argument 'member_group_ids' to be a list")
        pulumi.set(__self__, "member_group_ids", member_group_ids)
        if metadata and not isinstance(metadata, dict):
            raise TypeError("Expected argument 'metadata' to be a dict")
        pulumi.set(__self__, "metadata", metadata)
        if modify_index and not isinstance(modify_index, int):
            raise TypeError("Expected argument 'modify_index' to be a int")
        pulumi.set(__self__, "modify_index", modify_index)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if namespace_id and not isinstance(namespace_id, str):
            raise TypeError("Expected argument 'namespace_id' to be a str")
        pulumi.set(__self__, "namespace_id", namespace_id)
        if parent_group_ids and not isinstance(parent_group_ids, list):
            raise TypeError("Expected argument 'parent_group_ids' to be a list")
        pulumi.set(__self__, "parent_group_ids", parent_group_ids)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="aliasCanonicalId")
    def alias_canonical_id(self) -> str:
        """
        Canonical ID of the Alias
        """
        return pulumi.get(self, "alias_canonical_id")

    @property
    @pulumi.getter(name="aliasCreationTime")
    def alias_creation_time(self) -> str:
        """
        Creation time of the Alias
        """
        return pulumi.get(self, "alias_creation_time")

    @property
    @pulumi.getter(name="aliasId")
    def alias_id(self) -> str:
        return pulumi.get(self, "alias_id")

    @property
    @pulumi.getter(name="aliasLastUpdateTime")
    def alias_last_update_time(self) -> str:
        """
        Last update time of the alias
        """
        return pulumi.get(self, "alias_last_update_time")

    @property
    @pulumi.getter(name="aliasMergedFromCanonicalIds")
    def alias_merged_from_canonical_ids(self) -> Sequence[str]:
        """
        List of canonical IDs merged with this alias
        """
        return pulumi.get(self, "alias_merged_from_canonical_ids")

    @property
    @pulumi.getter(name="aliasMetadata")
    def alias_metadata(self) -> Mapping[str, Any]:
        """
        Arbitrary metadata
        """
        return pulumi.get(self, "alias_metadata")

    @property
    @pulumi.getter(name="aliasMountAccessor")
    def alias_mount_accessor(self) -> str:
        return pulumi.get(self, "alias_mount_accessor")

    @property
    @pulumi.getter(name="aliasMountPath")
    def alias_mount_path(self) -> str:
        """
        Authentication mount path which this alias belongs to
        """
        return pulumi.get(self, "alias_mount_path")

    @property
    @pulumi.getter(name="aliasMountType")
    def alias_mount_type(self) -> str:
        """
        Authentication mount type which this alias belongs to
        """
        return pulumi.get(self, "alias_mount_type")

    @property
    @pulumi.getter(name="aliasName")
    def alias_name(self) -> str:
        return pulumi.get(self, "alias_name")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> str:
        """
        Creation timestamp of the group
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter(name="dataJson")
    def data_json(self) -> str:
        """
        A string containing the full data payload retrieved from
        Vault, serialized in JSON format.
        """
        return pulumi.get(self, "data_json")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> str:
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> str:
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> str:
        """
        Last updated time of the group
        """
        return pulumi.get(self, "last_update_time")

    @property
    @pulumi.getter(name="memberEntityIds")
    def member_entity_ids(self) -> Sequence[str]:
        """
        List of Entity IDs which are members of this group
        """
        return pulumi.get(self, "member_entity_ids")

    @property
    @pulumi.getter(name="memberGroupIds")
    def member_group_ids(self) -> Sequence[str]:
        """
        List of Group IDs which are members of this group
        """
        return pulumi.get(self, "member_group_ids")

    @property
    @pulumi.getter
    def metadata(self) -> Mapping[str, Any]:
        """
        Arbitrary metadata
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter(name="modifyIndex")
    def modify_index(self) -> int:
        """
        Modify index of the group
        """
        return pulumi.get(self, "modify_index")

    @property
    @pulumi.getter
    def namespace(self) -> Optional[str]:
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> str:
        """
        Namespace of which the group is part of
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter(name="parentGroupIds")
    def parent_group_ids(self) -> Sequence[str]:
        """
        List of Group IDs which are parents of this group.
        """
        return pulumi.get(self, "parent_group_ids")

    @property
    @pulumi.getter
    def policies(self) -> Sequence[str]:
        """
        List of policies attached to the group
        """
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Type of group
        """
        return pulumi.get(self, "type")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            alias_canonical_id=self.alias_canonical_id,
            alias_creation_time=self.alias_creation_time,
            alias_id=self.alias_id,
            alias_last_update_time=self.alias_last_update_time,
            alias_merged_from_canonical_ids=self.alias_merged_from_canonical_ids,
            alias_metadata=self.alias_metadata,
            alias_mount_accessor=self.alias_mount_accessor,
            alias_mount_path=self.alias_mount_path,
            alias_mount_type=self.alias_mount_type,
            alias_name=self.alias_name,
            creation_time=self.creation_time,
            data_json=self.data_json,
            group_id=self.group_id,
            group_name=self.group_name,
            id=self.id,
            last_update_time=self.last_update_time,
            member_entity_ids=self.member_entity_ids,
            member_group_ids=self.member_group_ids,
            metadata=self.metadata,
            modify_index=self.modify_index,
            namespace=self.namespace,
            namespace_id=self.namespace_id,
            parent_group_ids=self.parent_group_ids,
            policies=self.policies,
            type=self.type)


def get_group(alias_id: Optional[str] = None,
              alias_mount_accessor: Optional[str] = None,
              alias_name: Optional[str] = None,
              group_id: Optional[str] = None,
              group_name: Optional[str] = None,
              namespace: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    group = vault.identity.get_group(group_name="user")
    ```
    ## Required Vault Capabilities

    Use of this resource requires the `create` capability on `/identity/lookup/group`.


    :param str alias_id: ID of the alias.
    :param str alias_mount_accessor: Accessor of the mount to which the alias belongs to.
           This should be supplied in conjunction with `alias_name`.
           
           The lookup criteria can be `group_name`, `group_id`, `alias_id`, or a combination of
           `alias_name` and `alias_mount_accessor`.
    :param str alias_name: Name of the alias. This should be supplied in conjunction with
           `alias_mount_accessor`.
    :param str group_id: ID of the group.
    :param str group_name: Name of the group.
    :param str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['aliasId'] = alias_id
    __args__['aliasMountAccessor'] = alias_mount_accessor
    __args__['aliasName'] = alias_name
    __args__['groupId'] = group_id
    __args__['groupName'] = group_name
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:identity/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        alias_canonical_id=pulumi.get(__ret__, 'alias_canonical_id'),
        alias_creation_time=pulumi.get(__ret__, 'alias_creation_time'),
        alias_id=pulumi.get(__ret__, 'alias_id'),
        alias_last_update_time=pulumi.get(__ret__, 'alias_last_update_time'),
        alias_merged_from_canonical_ids=pulumi.get(__ret__, 'alias_merged_from_canonical_ids'),
        alias_metadata=pulumi.get(__ret__, 'alias_metadata'),
        alias_mount_accessor=pulumi.get(__ret__, 'alias_mount_accessor'),
        alias_mount_path=pulumi.get(__ret__, 'alias_mount_path'),
        alias_mount_type=pulumi.get(__ret__, 'alias_mount_type'),
        alias_name=pulumi.get(__ret__, 'alias_name'),
        creation_time=pulumi.get(__ret__, 'creation_time'),
        data_json=pulumi.get(__ret__, 'data_json'),
        group_id=pulumi.get(__ret__, 'group_id'),
        group_name=pulumi.get(__ret__, 'group_name'),
        id=pulumi.get(__ret__, 'id'),
        last_update_time=pulumi.get(__ret__, 'last_update_time'),
        member_entity_ids=pulumi.get(__ret__, 'member_entity_ids'),
        member_group_ids=pulumi.get(__ret__, 'member_group_ids'),
        metadata=pulumi.get(__ret__, 'metadata'),
        modify_index=pulumi.get(__ret__, 'modify_index'),
        namespace=pulumi.get(__ret__, 'namespace'),
        namespace_id=pulumi.get(__ret__, 'namespace_id'),
        parent_group_ids=pulumi.get(__ret__, 'parent_group_ids'),
        policies=pulumi.get(__ret__, 'policies'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_group)
def get_group_output(alias_id: Optional[pulumi.Input[Optional[str]]] = None,
                     alias_mount_accessor: Optional[pulumi.Input[Optional[str]]] = None,
                     alias_name: Optional[pulumi.Input[Optional[str]]] = None,
                     group_id: Optional[pulumi.Input[Optional[str]]] = None,
                     group_name: Optional[pulumi.Input[Optional[str]]] = None,
                     namespace: Optional[pulumi.Input[Optional[str]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGroupResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    group = vault.identity.get_group(group_name="user")
    ```
    ## Required Vault Capabilities

    Use of this resource requires the `create` capability on `/identity/lookup/group`.


    :param str alias_id: ID of the alias.
    :param str alias_mount_accessor: Accessor of the mount to which the alias belongs to.
           This should be supplied in conjunction with `alias_name`.
           
           The lookup criteria can be `group_name`, `group_id`, `alias_id`, or a combination of
           `alias_name` and `alias_mount_accessor`.
    :param str alias_name: Name of the alias. This should be supplied in conjunction with
           `alias_mount_accessor`.
    :param str group_id: ID of the group.
    :param str group_name: Name of the group.
    :param str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
           *Available only for Vault Enterprise*.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetNomadAccessTokenResult',
    'AwaitableGetNomadAccessTokenResult',
    'get_nomad_access_token',
    'get_nomad_access_token_output',
]

@pulumi.output_type
class GetNomadAccessTokenResult:
    """
    A collection of values returned by getNomadAccessToken.
    """
    def __init__(__self__, accessor_id=None, backend=None, id=None, namespace=None, role=None, secret_id=None):
        if accessor_id and not isinstance(accessor_id, str):
            raise TypeError("Expected argument 'accessor_id' to be a str")
        pulumi.set(__self__, "accessor_id", accessor_id)
        if backend and not isinstance(backend, str):
            raise TypeError("Expected argument 'backend' to be a str")
        pulumi.set(__self__, "backend", backend)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)
        if secret_id and not isinstance(secret_id, str):
            raise TypeError("Expected argument 'secret_id' to be a str")
        pulumi.set(__self__, "secret_id", secret_id)

    @property
    @pulumi.getter(name="accessorId")
    def accessor_id(self) -> str:
        """
        The public identifier for a specific token. It can be used 
        to look up information about a token or to revoke a token.
        """
        return pulumi.get(self, "accessor_id")

    @property
    @pulumi.getter
    def backend(self) -> str:
        return pulumi.get(self, "backend")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def namespace(self) -> Optional[str]:
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def role(self) -> str:
        return pulumi.get(self, "role")

    @property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> str:
        """
        The token to be used when making requests to Nomad and should be kept private.
        """
        return pulumi.get(self, "secret_id")


class AwaitableGetNomadAccessTokenResult(GetNomadAccessTokenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNomadAccessTokenResult(
            accessor_id=self.accessor_id,
            backend=self.backend,
            id=self.id,
            namespace=self.namespace,
            role=self.role,
            secret_id=self.secret_id)


def get_nomad_access_token(backend: Optional[str] = None,
                           namespace: Optional[str] = None,
                           role: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNomadAccessTokenResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    config = vault.NomadSecretBackend("config",
        backend="nomad",
        description="test description",
        default_lease_ttl_seconds=3600,
        max_lease_ttl_seconds=7200,
        address="https://127.0.0.1:4646",
        token="ae20ceaa-...")
    test = vault.NomadSecretRole("test",
        backend=config.backend,
        role="test",
        type="client",
        policies=["readonly"])
    token = pulumi.Output.all(config.backend, test.role).apply(lambda backend, role: vault.get_nomad_access_token_output(backend=backend,
        role=role))
    ```


    :param str backend: The path to the Nomad secret backend to
           read credentials from, with no leading or trailing `/`s.
    :param str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
           *Available only for Vault Enterprise*.
    :param str role: The name of the Nomad secret backend role to generate
           a token for, with no leading or trailing `/`s.
    """
    __args__ = dict()
    __args__['backend'] = backend
    __args__['namespace'] = namespace
    __args__['role'] = role
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:index/getNomadAccessToken:getNomadAccessToken', __args__, opts=opts, typ=GetNomadAccessTokenResult).value

    return AwaitableGetNomadAccessTokenResult(
        accessor_id=pulumi.get(__ret__, 'accessor_id'),
        backend=pulumi.get(__ret__, 'backend'),
        id=pulumi.get(__ret__, 'id'),
        namespace=pulumi.get(__ret__, 'namespace'),
        role=pulumi.get(__ret__, 'role'),
        secret_id=pulumi.get(__ret__, 'secret_id'))


@_utilities.lift_output_func(get_nomad_access_token)
def get_nomad_access_token_output(backend: Optional[pulumi.Input[str]] = None,
                                  namespace: Optional[pulumi.Input[Optional[str]]] = None,
                                  role: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNomadAccessTokenResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    config = vault.NomadSecretBackend("config",
        backend="nomad",
        description="test description",
        default_lease_ttl_seconds=3600,
        max_lease_ttl_seconds=7200,
        address="https://127.0.0.1:4646",
        token="ae20ceaa-...")
    test = vault.NomadSecretRole("test",
        backend=config.backend,
        role="test",
        type="client",
        policies=["readonly"])
    token = pulumi.Output.all(config.backend, test.role).apply(lambda backend, role: vault.get_nomad_access_token_output(backend=backend,
        role=role))
    ```


    :param str backend: The path to the Nomad secret backend to
           read credentials from, with no leading or trailing `/`s.
    :param str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
           *Available only for Vault Enterprise*.
    :param str role: The name of the Nomad secret backend role to generate
           a token for, with no leading or trailing `/`s.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['RaftSnapshotAgentConfigArgs', 'RaftSnapshotAgentConfig']

@pulumi.input_type
class RaftSnapshotAgentConfigArgs:
    def __init__(__self__, *,
                 interval_seconds: pulumi.Input[int],
                 path_prefix: pulumi.Input[str],
                 storage_type: pulumi.Input[str],
                 aws_access_key_id: Optional[pulumi.Input[str]] = None,
                 aws_s3_bucket: Optional[pulumi.Input[str]] = None,
                 aws_s3_disable_tls: Optional[pulumi.Input[bool]] = None,
                 aws_s3_enable_kms: Optional[pulumi.Input[bool]] = None,
                 aws_s3_endpoint: Optional[pulumi.Input[str]] = None,
                 aws_s3_force_path_style: Optional[pulumi.Input[bool]] = None,
                 aws_s3_kms_key: Optional[pulumi.Input[str]] = None,
                 aws_s3_region: Optional[pulumi.Input[str]] = None,
                 aws_s3_server_side_encryption: Optional[pulumi.Input[bool]] = None,
                 aws_secret_access_key: Optional[pulumi.Input[str]] = None,
                 aws_session_token: Optional[pulumi.Input[str]] = None,
                 azure_account_key: Optional[pulumi.Input[str]] = None,
                 azure_account_name: Optional[pulumi.Input[str]] = None,
                 azure_blob_environment: Optional[pulumi.Input[str]] = None,
                 azure_container_name: Optional[pulumi.Input[str]] = None,
                 azure_endpoint: Optional[pulumi.Input[str]] = None,
                 file_prefix: Optional[pulumi.Input[str]] = None,
                 google_disable_tls: Optional[pulumi.Input[bool]] = None,
                 google_endpoint: Optional[pulumi.Input[str]] = None,
                 google_gcs_bucket: Optional[pulumi.Input[str]] = None,
                 google_service_account_key: Optional[pulumi.Input[str]] = None,
                 local_max_space: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 retain: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a RaftSnapshotAgentConfig resource.
        :param pulumi.Input[int] interval_seconds: `<required>` - Time (in seconds) between snapshots.
        :param pulumi.Input[str] path_prefix: `<required>` - For `storage_type = "local"`, the directory to
               write the snapshots in. For cloud storage types, the bucket prefix to use.
               Types `azure-s3` and `google-gcs` require a trailing `/` (slash).
               Types `local` and `aws-s3` the trailing `/` is optional.
        :param pulumi.Input[str] storage_type: `<required>` - One of "local", "azure-blob", "aws-s3",
               or "google-gcs". The remaining parameters described below are all specific to
               the selected `storage_type` and prefixed accordingly.
        :param pulumi.Input[str] aws_access_key_id: AWS access key ID.
        :param pulumi.Input[str] aws_s3_bucket: `<required>` - S3 bucket to write snapshots to.
        :param pulumi.Input[bool] aws_s3_disable_tls: Disable TLS for the S3 endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `aws_s3_endpoint`.
        :param pulumi.Input[bool] aws_s3_enable_kms: Use KMS to encrypt bucket contents.
        :param pulumi.Input[str] aws_s3_endpoint: AWS endpoint. This is typically only set when
               using a non-AWS S3 implementation like Minio.
        :param pulumi.Input[bool] aws_s3_force_path_style: Use the endpoint/bucket URL style
               instead of bucket.endpoint. May be needed when setting `aws_s3_endpoint`.
        :param pulumi.Input[str] aws_s3_kms_key: Use named KMS key, when `aws_s3_enable_kms = true`
        :param pulumi.Input[str] aws_s3_region: `<required>` - AWS region bucket is in.
        :param pulumi.Input[bool] aws_s3_server_side_encryption: Use AES256 to encrypt bucket contents.
        :param pulumi.Input[str] aws_secret_access_key: AWS secret access key.
        :param pulumi.Input[str] aws_session_token: AWS session token.
        :param pulumi.Input[str] azure_account_key: Azure account key.
        :param pulumi.Input[str] azure_account_name: Azure account name.
        :param pulumi.Input[str] azure_blob_environment: Azure blob environment.
        :param pulumi.Input[str] azure_container_name: `<required>` - Azure container name to write
               snapshots to.
        :param pulumi.Input[str] azure_endpoint: Azure blob storage endpoint. This is typically
               only set when using a non-Azure implementation like Azurite.
        :param pulumi.Input[str] file_prefix: Within the directory or bucket
               prefix given by `path_prefix`, the file or object name of snapshot files
               will start with this string.
        :param pulumi.Input[bool] google_disable_tls: Disable TLS for the GCS endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `google_endpoint`.
        :param pulumi.Input[str] google_endpoint: GCS endpoint. This is typically only set when
               using a non-Google GCS implementation like fake-gcs-server.
        :param pulumi.Input[str] google_gcs_bucket: `<required>` - GCS bucket to write snapshots to.
        :param pulumi.Input[str] google_service_account_key: Google service account key in JSON format. 
               The raw value looks like this:
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[int] local_max_space: For `storage_type = local`, the maximum
               space, in bytes, to use for snapshots. Snapshot attempts will fail if there is not enough
               space left in this allowance.
        :param pulumi.Input[str] name: `<required>` – Name of the configuration to modify.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[int] retain: How many snapshots are to be kept; when writing a
               snapshot, if there are more snapshots already stored than this number, the
               oldest ones will be deleted.
        """
        pulumi.set(__self__, "interval_seconds", interval_seconds)
        pulumi.set(__self__, "path_prefix", path_prefix)
        pulumi.set(__self__, "storage_type", storage_type)
        if aws_access_key_id is not None:
            pulumi.set(__self__, "aws_access_key_id", aws_access_key_id)
        if aws_s3_bucket is not None:
            pulumi.set(__self__, "aws_s3_bucket", aws_s3_bucket)
        if aws_s3_disable_tls is not None:
            pulumi.set(__self__, "aws_s3_disable_tls", aws_s3_disable_tls)
        if aws_s3_enable_kms is not None:
            pulumi.set(__self__, "aws_s3_enable_kms", aws_s3_enable_kms)
        if aws_s3_endpoint is not None:
            pulumi.set(__self__, "aws_s3_endpoint", aws_s3_endpoint)
        if aws_s3_force_path_style is not None:
            pulumi.set(__self__, "aws_s3_force_path_style", aws_s3_force_path_style)
        if aws_s3_kms_key is not None:
            pulumi.set(__self__, "aws_s3_kms_key", aws_s3_kms_key)
        if aws_s3_region is not None:
            pulumi.set(__self__, "aws_s3_region", aws_s3_region)
        if aws_s3_server_side_encryption is not None:
            pulumi.set(__self__, "aws_s3_server_side_encryption", aws_s3_server_side_encryption)
        if aws_secret_access_key is not None:
            pulumi.set(__self__, "aws_secret_access_key", aws_secret_access_key)
        if aws_session_token is not None:
            pulumi.set(__self__, "aws_session_token", aws_session_token)
        if azure_account_key is not None:
            pulumi.set(__self__, "azure_account_key", azure_account_key)
        if azure_account_name is not None:
            pulumi.set(__self__, "azure_account_name", azure_account_name)
        if azure_blob_environment is not None:
            pulumi.set(__self__, "azure_blob_environment", azure_blob_environment)
        if azure_container_name is not None:
            pulumi.set(__self__, "azure_container_name", azure_container_name)
        if azure_endpoint is not None:
            pulumi.set(__self__, "azure_endpoint", azure_endpoint)
        if file_prefix is not None:
            pulumi.set(__self__, "file_prefix", file_prefix)
        if google_disable_tls is not None:
            pulumi.set(__self__, "google_disable_tls", google_disable_tls)
        if google_endpoint is not None:
            pulumi.set(__self__, "google_endpoint", google_endpoint)
        if google_gcs_bucket is not None:
            pulumi.set(__self__, "google_gcs_bucket", google_gcs_bucket)
        if google_service_account_key is not None:
            pulumi.set(__self__, "google_service_account_key", google_service_account_key)
        if local_max_space is not None:
            pulumi.set(__self__, "local_max_space", local_max_space)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if retain is not None:
            pulumi.set(__self__, "retain", retain)

    @property
    @pulumi.getter(name="intervalSeconds")
    def interval_seconds(self) -> pulumi.Input[int]:
        """
        `<required>` - Time (in seconds) between snapshots.
        """
        return pulumi.get(self, "interval_seconds")

    @interval_seconds.setter
    def interval_seconds(self, value: pulumi.Input[int]):
        pulumi.set(self, "interval_seconds", value)

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> pulumi.Input[str]:
        """
        `<required>` - For `storage_type = "local"`, the directory to
        write the snapshots in. For cloud storage types, the bucket prefix to use.
        Types `azure-s3` and `google-gcs` require a trailing `/` (slash).
        Types `local` and `aws-s3` the trailing `/` is optional.
        """
        return pulumi.get(self, "path_prefix")

    @path_prefix.setter
    def path_prefix(self, value: pulumi.Input[str]):
        pulumi.set(self, "path_prefix", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Input[str]:
        """
        `<required>` - One of "local", "azure-blob", "aws-s3",
        or "google-gcs". The remaining parameters described below are all specific to
        the selected `storage_type` and prefixed accordingly.
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter(name="awsAccessKeyId")
    def aws_access_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        AWS access key ID.
        """
        return pulumi.get(self, "aws_access_key_id")

    @aws_access_key_id.setter
    def aws_access_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_access_key_id", value)

    @property
    @pulumi.getter(name="awsS3Bucket")
    def aws_s3_bucket(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - S3 bucket to write snapshots to.
        """
        return pulumi.get(self, "aws_s3_bucket")

    @aws_s3_bucket.setter
    def aws_s3_bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_bucket", value)

    @property
    @pulumi.getter(name="awsS3DisableTls")
    def aws_s3_disable_tls(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable TLS for the S3 endpoint. This
        should only be used for testing purposes, typically in conjunction with
        `aws_s3_endpoint`.
        """
        return pulumi.get(self, "aws_s3_disable_tls")

    @aws_s3_disable_tls.setter
    def aws_s3_disable_tls(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_disable_tls", value)

    @property
    @pulumi.getter(name="awsS3EnableKms")
    def aws_s3_enable_kms(self) -> Optional[pulumi.Input[bool]]:
        """
        Use KMS to encrypt bucket contents.
        """
        return pulumi.get(self, "aws_s3_enable_kms")

    @aws_s3_enable_kms.setter
    def aws_s3_enable_kms(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_enable_kms", value)

    @property
    @pulumi.getter(name="awsS3Endpoint")
    def aws_s3_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        AWS endpoint. This is typically only set when
        using a non-AWS S3 implementation like Minio.
        """
        return pulumi.get(self, "aws_s3_endpoint")

    @aws_s3_endpoint.setter
    def aws_s3_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_endpoint", value)

    @property
    @pulumi.getter(name="awsS3ForcePathStyle")
    def aws_s3_force_path_style(self) -> Optional[pulumi.Input[bool]]:
        """
        Use the endpoint/bucket URL style
        instead of bucket.endpoint. May be needed when setting `aws_s3_endpoint`.
        """
        return pulumi.get(self, "aws_s3_force_path_style")

    @aws_s3_force_path_style.setter
    def aws_s3_force_path_style(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_force_path_style", value)

    @property
    @pulumi.getter(name="awsS3KmsKey")
    def aws_s3_kms_key(self) -> Optional[pulumi.Input[str]]:
        """
        Use named KMS key, when `aws_s3_enable_kms = true`
        """
        return pulumi.get(self, "aws_s3_kms_key")

    @aws_s3_kms_key.setter
    def aws_s3_kms_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_kms_key", value)

    @property
    @pulumi.getter(name="awsS3Region")
    def aws_s3_region(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - AWS region bucket is in.
        """
        return pulumi.get(self, "aws_s3_region")

    @aws_s3_region.setter
    def aws_s3_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_region", value)

    @property
    @pulumi.getter(name="awsS3ServerSideEncryption")
    def aws_s3_server_side_encryption(self) -> Optional[pulumi.Input[bool]]:
        """
        Use AES256 to encrypt bucket contents.
        """
        return pulumi.get(self, "aws_s3_server_side_encryption")

    @aws_s3_server_side_encryption.setter
    def aws_s3_server_side_encryption(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_server_side_encryption", value)

    @property
    @pulumi.getter(name="awsSecretAccessKey")
    def aws_secret_access_key(self) -> Optional[pulumi.Input[str]]:
        """
        AWS secret access key.
        """
        return pulumi.get(self, "aws_secret_access_key")

    @aws_secret_access_key.setter
    def aws_secret_access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_secret_access_key", value)

    @property
    @pulumi.getter(name="awsSessionToken")
    def aws_session_token(self) -> Optional[pulumi.Input[str]]:
        """
        AWS session token.
        """
        return pulumi.get(self, "aws_session_token")

    @aws_session_token.setter
    def aws_session_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_session_token", value)

    @property
    @pulumi.getter(name="azureAccountKey")
    def azure_account_key(self) -> Optional[pulumi.Input[str]]:
        """
        Azure account key.
        """
        return pulumi.get(self, "azure_account_key")

    @azure_account_key.setter
    def azure_account_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_account_key", value)

    @property
    @pulumi.getter(name="azureAccountName")
    def azure_account_name(self) -> Optional[pulumi.Input[str]]:
        """
        Azure account name.
        """
        return pulumi.get(self, "azure_account_name")

    @azure_account_name.setter
    def azure_account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_account_name", value)

    @property
    @pulumi.getter(name="azureBlobEnvironment")
    def azure_blob_environment(self) -> Optional[pulumi.Input[str]]:
        """
        Azure blob environment.
        """
        return pulumi.get(self, "azure_blob_environment")

    @azure_blob_environment.setter
    def azure_blob_environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_blob_environment", value)

    @property
    @pulumi.getter(name="azureContainerName")
    def azure_container_name(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - Azure container name to write
        snapshots to.
        """
        return pulumi.get(self, "azure_container_name")

    @azure_container_name.setter
    def azure_container_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_container_name", value)

    @property
    @pulumi.getter(name="azureEndpoint")
    def azure_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        Azure blob storage endpoint. This is typically
        only set when using a non-Azure implementation like Azurite.
        """
        return pulumi.get(self, "azure_endpoint")

    @azure_endpoint.setter
    def azure_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_endpoint", value)

    @property
    @pulumi.getter(name="filePrefix")
    def file_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Within the directory or bucket
        prefix given by `path_prefix`, the file or object name of snapshot files
        will start with this string.
        """
        return pulumi.get(self, "file_prefix")

    @file_prefix.setter
    def file_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_prefix", value)

    @property
    @pulumi.getter(name="googleDisableTls")
    def google_disable_tls(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable TLS for the GCS endpoint. This
        should only be used for testing purposes, typically in conjunction with
        `google_endpoint`.
        """
        return pulumi.get(self, "google_disable_tls")

    @google_disable_tls.setter
    def google_disable_tls(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "google_disable_tls", value)

    @property
    @pulumi.getter(name="googleEndpoint")
    def google_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        GCS endpoint. This is typically only set when
        using a non-Google GCS implementation like fake-gcs-server.
        """
        return pulumi.get(self, "google_endpoint")

    @google_endpoint.setter
    def google_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "google_endpoint", value)

    @property
    @pulumi.getter(name="googleGcsBucket")
    def google_gcs_bucket(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - GCS bucket to write snapshots to.
        """
        return pulumi.get(self, "google_gcs_bucket")

    @google_gcs_bucket.setter
    def google_gcs_bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "google_gcs_bucket", value)

    @property
    @pulumi.getter(name="googleServiceAccountKey")
    def google_service_account_key(self) -> Optional[pulumi.Input[str]]:
        """
        Google service account key in JSON format. 
        The raw value looks like this:

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "google_service_account_key")

    @google_service_account_key.setter
    def google_service_account_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "google_service_account_key", value)

    @property
    @pulumi.getter(name="localMaxSpace")
    def local_max_space(self) -> Optional[pulumi.Input[int]]:
        """
        For `storage_type = local`, the maximum
        space, in bytes, to use for snapshots. Snapshot attempts will fail if there is not enough
        space left in this allowance.
        """
        return pulumi.get(self, "local_max_space")

    @local_max_space.setter
    def local_max_space(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "local_max_space", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` – Name of the configuration to modify.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def retain(self) -> Optional[pulumi.Input[int]]:
        """
        How many snapshots are to be kept; when writing a
        snapshot, if there are more snapshots already stored than this number, the
        oldest ones will be deleted.
        """
        return pulumi.get(self, "retain")

    @retain.setter
    def retain(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retain", value)


@pulumi.input_type
class _RaftSnapshotAgentConfigState:
    def __init__(__self__, *,
                 aws_access_key_id: Optional[pulumi.Input[str]] = None,
                 aws_s3_bucket: Optional[pulumi.Input[str]] = None,
                 aws_s3_disable_tls: Optional[pulumi.Input[bool]] = None,
                 aws_s3_enable_kms: Optional[pulumi.Input[bool]] = None,
                 aws_s3_endpoint: Optional[pulumi.Input[str]] = None,
                 aws_s3_force_path_style: Optional[pulumi.Input[bool]] = None,
                 aws_s3_kms_key: Optional[pulumi.Input[str]] = None,
                 aws_s3_region: Optional[pulumi.Input[str]] = None,
                 aws_s3_server_side_encryption: Optional[pulumi.Input[bool]] = None,
                 aws_secret_access_key: Optional[pulumi.Input[str]] = None,
                 aws_session_token: Optional[pulumi.Input[str]] = None,
                 azure_account_key: Optional[pulumi.Input[str]] = None,
                 azure_account_name: Optional[pulumi.Input[str]] = None,
                 azure_blob_environment: Optional[pulumi.Input[str]] = None,
                 azure_container_name: Optional[pulumi.Input[str]] = None,
                 azure_endpoint: Optional[pulumi.Input[str]] = None,
                 file_prefix: Optional[pulumi.Input[str]] = None,
                 google_disable_tls: Optional[pulumi.Input[bool]] = None,
                 google_endpoint: Optional[pulumi.Input[str]] = None,
                 google_gcs_bucket: Optional[pulumi.Input[str]] = None,
                 google_service_account_key: Optional[pulumi.Input[str]] = None,
                 interval_seconds: Optional[pulumi.Input[int]] = None,
                 local_max_space: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path_prefix: Optional[pulumi.Input[str]] = None,
                 retain: Optional[pulumi.Input[int]] = None,
                 storage_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RaftSnapshotAgentConfig resources.
        :param pulumi.Input[str] aws_access_key_id: AWS access key ID.
        :param pulumi.Input[str] aws_s3_bucket: `<required>` - S3 bucket to write snapshots to.
        :param pulumi.Input[bool] aws_s3_disable_tls: Disable TLS for the S3 endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `aws_s3_endpoint`.
        :param pulumi.Input[bool] aws_s3_enable_kms: Use KMS to encrypt bucket contents.
        :param pulumi.Input[str] aws_s3_endpoint: AWS endpoint. This is typically only set when
               using a non-AWS S3 implementation like Minio.
        :param pulumi.Input[bool] aws_s3_force_path_style: Use the endpoint/bucket URL style
               instead of bucket.endpoint. May be needed when setting `aws_s3_endpoint`.
        :param pulumi.Input[str] aws_s3_kms_key: Use named KMS key, when `aws_s3_enable_kms = true`
        :param pulumi.Input[str] aws_s3_region: `<required>` - AWS region bucket is in.
        :param pulumi.Input[bool] aws_s3_server_side_encryption: Use AES256 to encrypt bucket contents.
        :param pulumi.Input[str] aws_secret_access_key: AWS secret access key.
        :param pulumi.Input[str] aws_session_token: AWS session token.
        :param pulumi.Input[str] azure_account_key: Azure account key.
        :param pulumi.Input[str] azure_account_name: Azure account name.
        :param pulumi.Input[str] azure_blob_environment: Azure blob environment.
        :param pulumi.Input[str] azure_container_name: `<required>` - Azure container name to write
               snapshots to.
        :param pulumi.Input[str] azure_endpoint: Azure blob storage endpoint. This is typically
               only set when using a non-Azure implementation like Azurite.
        :param pulumi.Input[str] file_prefix: Within the directory or bucket
               prefix given by `path_prefix`, the file or object name of snapshot files
               will start with this string.
        :param pulumi.Input[bool] google_disable_tls: Disable TLS for the GCS endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `google_endpoint`.
        :param pulumi.Input[str] google_endpoint: GCS endpoint. This is typically only set when
               using a non-Google GCS implementation like fake-gcs-server.
        :param pulumi.Input[str] google_gcs_bucket: `<required>` - GCS bucket to write snapshots to.
        :param pulumi.Input[str] google_service_account_key: Google service account key in JSON format. 
               The raw value looks like this:
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[int] interval_seconds: `<required>` - Time (in seconds) between snapshots.
        :param pulumi.Input[int] local_max_space: For `storage_type = local`, the maximum
               space, in bytes, to use for snapshots. Snapshot attempts will fail if there is not enough
               space left in this allowance.
        :param pulumi.Input[str] name: `<required>` – Name of the configuration to modify.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path_prefix: `<required>` - For `storage_type = "local"`, the directory to
               write the snapshots in. For cloud storage types, the bucket prefix to use.
               Types `azure-s3` and `google-gcs` require a trailing `/` (slash).
               Types `local` and `aws-s3` the trailing `/` is optional.
        :param pulumi.Input[int] retain: How many snapshots are to be kept; when writing a
               snapshot, if there are more snapshots already stored than this number, the
               oldest ones will be deleted.
        :param pulumi.Input[str] storage_type: `<required>` - One of "local", "azure-blob", "aws-s3",
               or "google-gcs". The remaining parameters described below are all specific to
               the selected `storage_type` and prefixed accordingly.
        """
        if aws_access_key_id is not None:
            pulumi.set(__self__, "aws_access_key_id", aws_access_key_id)
        if aws_s3_bucket is not None:
            pulumi.set(__self__, "aws_s3_bucket", aws_s3_bucket)
        if aws_s3_disable_tls is not None:
            pulumi.set(__self__, "aws_s3_disable_tls", aws_s3_disable_tls)
        if aws_s3_enable_kms is not None:
            pulumi.set(__self__, "aws_s3_enable_kms", aws_s3_enable_kms)
        if aws_s3_endpoint is not None:
            pulumi.set(__self__, "aws_s3_endpoint", aws_s3_endpoint)
        if aws_s3_force_path_style is not None:
            pulumi.set(__self__, "aws_s3_force_path_style", aws_s3_force_path_style)
        if aws_s3_kms_key is not None:
            pulumi.set(__self__, "aws_s3_kms_key", aws_s3_kms_key)
        if aws_s3_region is not None:
            pulumi.set(__self__, "aws_s3_region", aws_s3_region)
        if aws_s3_server_side_encryption is not None:
            pulumi.set(__self__, "aws_s3_server_side_encryption", aws_s3_server_side_encryption)
        if aws_secret_access_key is not None:
            pulumi.set(__self__, "aws_secret_access_key", aws_secret_access_key)
        if aws_session_token is not None:
            pulumi.set(__self__, "aws_session_token", aws_session_token)
        if azure_account_key is not None:
            pulumi.set(__self__, "azure_account_key", azure_account_key)
        if azure_account_name is not None:
            pulumi.set(__self__, "azure_account_name", azure_account_name)
        if azure_blob_environment is not None:
            pulumi.set(__self__, "azure_blob_environment", azure_blob_environment)
        if azure_container_name is not None:
            pulumi.set(__self__, "azure_container_name", azure_container_name)
        if azure_endpoint is not None:
            pulumi.set(__self__, "azure_endpoint", azure_endpoint)
        if file_prefix is not None:
            pulumi.set(__self__, "file_prefix", file_prefix)
        if google_disable_tls is not None:
            pulumi.set(__self__, "google_disable_tls", google_disable_tls)
        if google_endpoint is not None:
            pulumi.set(__self__, "google_endpoint", google_endpoint)
        if google_gcs_bucket is not None:
            pulumi.set(__self__, "google_gcs_bucket", google_gcs_bucket)
        if google_service_account_key is not None:
            pulumi.set(__self__, "google_service_account_key", google_service_account_key)
        if interval_seconds is not None:
            pulumi.set(__self__, "interval_seconds", interval_seconds)
        if local_max_space is not None:
            pulumi.set(__self__, "local_max_space", local_max_space)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if path_prefix is not None:
            pulumi.set(__self__, "path_prefix", path_prefix)
        if retain is not None:
            pulumi.set(__self__, "retain", retain)
        if storage_type is not None:
            pulumi.set(__self__, "storage_type", storage_type)

    @property
    @pulumi.getter(name="awsAccessKeyId")
    def aws_access_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        AWS access key ID.
        """
        return pulumi.get(self, "aws_access_key_id")

    @aws_access_key_id.setter
    def aws_access_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_access_key_id", value)

    @property
    @pulumi.getter(name="awsS3Bucket")
    def aws_s3_bucket(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - S3 bucket to write snapshots to.
        """
        return pulumi.get(self, "aws_s3_bucket")

    @aws_s3_bucket.setter
    def aws_s3_bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_bucket", value)

    @property
    @pulumi.getter(name="awsS3DisableTls")
    def aws_s3_disable_tls(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable TLS for the S3 endpoint. This
        should only be used for testing purposes, typically in conjunction with
        `aws_s3_endpoint`.
        """
        return pulumi.get(self, "aws_s3_disable_tls")

    @aws_s3_disable_tls.setter
    def aws_s3_disable_tls(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_disable_tls", value)

    @property
    @pulumi.getter(name="awsS3EnableKms")
    def aws_s3_enable_kms(self) -> Optional[pulumi.Input[bool]]:
        """
        Use KMS to encrypt bucket contents.
        """
        return pulumi.get(self, "aws_s3_enable_kms")

    @aws_s3_enable_kms.setter
    def aws_s3_enable_kms(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_enable_kms", value)

    @property
    @pulumi.getter(name="awsS3Endpoint")
    def aws_s3_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        AWS endpoint. This is typically only set when
        using a non-AWS S3 implementation like Minio.
        """
        return pulumi.get(self, "aws_s3_endpoint")

    @aws_s3_endpoint.setter
    def aws_s3_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_endpoint", value)

    @property
    @pulumi.getter(name="awsS3ForcePathStyle")
    def aws_s3_force_path_style(self) -> Optional[pulumi.Input[bool]]:
        """
        Use the endpoint/bucket URL style
        instead of bucket.endpoint. May be needed when setting `aws_s3_endpoint`.
        """
        return pulumi.get(self, "aws_s3_force_path_style")

    @aws_s3_force_path_style.setter
    def aws_s3_force_path_style(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_force_path_style", value)

    @property
    @pulumi.getter(name="awsS3KmsKey")
    def aws_s3_kms_key(self) -> Optional[pulumi.Input[str]]:
        """
        Use named KMS key, when `aws_s3_enable_kms = true`
        """
        return pulumi.get(self, "aws_s3_kms_key")

    @aws_s3_kms_key.setter
    def aws_s3_kms_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_kms_key", value)

    @property
    @pulumi.getter(name="awsS3Region")
    def aws_s3_region(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - AWS region bucket is in.
        """
        return pulumi.get(self, "aws_s3_region")

    @aws_s3_region.setter
    def aws_s3_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_s3_region", value)

    @property
    @pulumi.getter(name="awsS3ServerSideEncryption")
    def aws_s3_server_side_encryption(self) -> Optional[pulumi.Input[bool]]:
        """
        Use AES256 to encrypt bucket contents.
        """
        return pulumi.get(self, "aws_s3_server_side_encryption")

    @aws_s3_server_side_encryption.setter
    def aws_s3_server_side_encryption(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "aws_s3_server_side_encryption", value)

    @property
    @pulumi.getter(name="awsSecretAccessKey")
    def aws_secret_access_key(self) -> Optional[pulumi.Input[str]]:
        """
        AWS secret access key.
        """
        return pulumi.get(self, "aws_secret_access_key")

    @aws_secret_access_key.setter
    def aws_secret_access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_secret_access_key", value)

    @property
    @pulumi.getter(name="awsSessionToken")
    def aws_session_token(self) -> Optional[pulumi.Input[str]]:
        """
        AWS session token.
        """
        return pulumi.get(self, "aws_session_token")

    @aws_session_token.setter
    def aws_session_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_session_token", value)

    @property
    @pulumi.getter(name="azureAccountKey")
    def azure_account_key(self) -> Optional[pulumi.Input[str]]:
        """
        Azure account key.
        """
        return pulumi.get(self, "azure_account_key")

    @azure_account_key.setter
    def azure_account_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_account_key", value)

    @property
    @pulumi.getter(name="azureAccountName")
    def azure_account_name(self) -> Optional[pulumi.Input[str]]:
        """
        Azure account name.
        """
        return pulumi.get(self, "azure_account_name")

    @azure_account_name.setter
    def azure_account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_account_name", value)

    @property
    @pulumi.getter(name="azureBlobEnvironment")
    def azure_blob_environment(self) -> Optional[pulumi.Input[str]]:
        """
        Azure blob environment.
        """
        return pulumi.get(self, "azure_blob_environment")

    @azure_blob_environment.setter
    def azure_blob_environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_blob_environment", value)

    @property
    @pulumi.getter(name="azureContainerName")
    def azure_container_name(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - Azure container name to write
        snapshots to.
        """
        return pulumi.get(self, "azure_container_name")

    @azure_container_name.setter
    def azure_container_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_container_name", value)

    @property
    @pulumi.getter(name="azureEndpoint")
    def azure_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        Azure blob storage endpoint. This is typically
        only set when using a non-Azure implementation like Azurite.
        """
        return pulumi.get(self, "azure_endpoint")

    @azure_endpoint.setter
    def azure_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "azure_endpoint", value)

    @property
    @pulumi.getter(name="filePrefix")
    def file_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Within the directory or bucket
        prefix given by `path_prefix`, the file or object name of snapshot files
        will start with this string.
        """
        return pulumi.get(self, "file_prefix")

    @file_prefix.setter
    def file_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_prefix", value)

    @property
    @pulumi.getter(name="googleDisableTls")
    def google_disable_tls(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable TLS for the GCS endpoint. This
        should only be used for testing purposes, typically in conjunction with
        `google_endpoint`.
        """
        return pulumi.get(self, "google_disable_tls")

    @google_disable_tls.setter
    def google_disable_tls(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "google_disable_tls", value)

    @property
    @pulumi.getter(name="googleEndpoint")
    def google_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        GCS endpoint. This is typically only set when
        using a non-Google GCS implementation like fake-gcs-server.
        """
        return pulumi.get(self, "google_endpoint")

    @google_endpoint.setter
    def google_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "google_endpoint", value)

    @property
    @pulumi.getter(name="googleGcsBucket")
    def google_gcs_bucket(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - GCS bucket to write snapshots to.
        """
        return pulumi.get(self, "google_gcs_bucket")

    @google_gcs_bucket.setter
    def google_gcs_bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "google_gcs_bucket", value)

    @property
    @pulumi.getter(name="googleServiceAccountKey")
    def google_service_account_key(self) -> Optional[pulumi.Input[str]]:
        """
        Google service account key in JSON format. 
        The raw value looks like this:

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "google_service_account_key")

    @google_service_account_key.setter
    def google_service_account_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "google_service_account_key", value)

    @property
    @pulumi.getter(name="intervalSeconds")
    def interval_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        `<required>` - Time (in seconds) between snapshots.
        """
        return pulumi.get(self, "interval_seconds")

    @interval_seconds.setter
    def interval_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "interval_seconds", value)

    @property
    @pulumi.getter(name="localMaxSpace")
    def local_max_space(self) -> Optional[pulumi.Input[int]]:
        """
        For `storage_type = local`, the maximum
        space, in bytes, to use for snapshots. Snapshot attempts will fail if there is not enough
        space left in this allowance.
        """
        return pulumi.get(self, "local_max_space")

    @local_max_space.setter
    def local_max_space(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "local_max_space", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` – Name of the configuration to modify.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - For `storage_type = "local"`, the directory to
        write the snapshots in. For cloud storage types, the bucket prefix to use.
        Types `azure-s3` and `google-gcs` require a trailing `/` (slash).
        Types `local` and `aws-s3` the trailing `/` is optional.
        """
        return pulumi.get(self, "path_prefix")

    @path_prefix.setter
    def path_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path_prefix", value)

    @property
    @pulumi.getter
    def retain(self) -> Optional[pulumi.Input[int]]:
        """
        How many snapshots are to be kept; when writing a
        snapshot, if there are more snapshots already stored than this number, the
        oldest ones will be deleted.
        """
        return pulumi.get(self, "retain")

    @retain.setter
    def retain(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retain", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> Optional[pulumi.Input[str]]:
        """
        `<required>` - One of "local", "azure-blob", "aws-s3",
        or "google-gcs". The remaining parameters described below are all specific to
        the selected `storage_type` and prefixed accordingly.
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_type", value)


class RaftSnapshotAgentConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_access_key_id: Optional[pulumi.Input[str]] = None,
                 aws_s3_bucket: Optional[pulumi.Input[str]] = None,
                 aws_s3_disable_tls: Optional[pulumi.Input[bool]] = None,
                 aws_s3_enable_kms: Optional[pulumi.Input[bool]] = None,
                 aws_s3_endpoint: Optional[pulumi.Input[str]] = None,
                 aws_s3_force_path_style: Optional[pulumi.Input[bool]] = None,
                 aws_s3_kms_key: Optional[pulumi.Input[str]] = None,
                 aws_s3_region: Optional[pulumi.Input[str]] = None,
                 aws_s3_server_side_encryption: Optional[pulumi.Input[bool]] = None,
                 aws_secret_access_key: Optional[pulumi.Input[str]] = None,
                 aws_session_token: Optional[pulumi.Input[str]] = None,
                 azure_account_key: Optional[pulumi.Input[str]] = None,
                 azure_account_name: Optional[pulumi.Input[str]] = None,
                 azure_blob_environment: Optional[pulumi.Input[str]] = None,
                 azure_container_name: Optional[pulumi.Input[str]] = None,
                 azure_endpoint: Optional[pulumi.Input[str]] = None,
                 file_prefix: Optional[pulumi.Input[str]] = None,
                 google_disable_tls: Optional[pulumi.Input[bool]] = None,
                 google_endpoint: Optional[pulumi.Input[str]] = None,
                 google_gcs_bucket: Optional[pulumi.Input[str]] = None,
                 google_service_account_key: Optional[pulumi.Input[str]] = None,
                 interval_seconds: Optional[pulumi.Input[int]] = None,
                 local_max_space: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path_prefix: Optional[pulumi.Input[str]] = None,
                 retain: Optional[pulumi.Input[int]] = None,
                 storage_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage
        ### Local Storage
        ```python
        import pulumi
        import pulumi_vault as vault

        local_backups = vault.RaftSnapshotAgentConfig("localBackups",
            interval_seconds=86400,
            local_max_space=10000000,
            path_prefix="/opt/vault/snapshots/",
            retain=7,
            storage_type="local")
        ```
        ### AWS S3
        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_vault as vault

        config = pulumi.Config()
        aws_access_key_id = config.require_object("awsAccessKeyId")
        aws_secret_access_key = config.require_object("awsSecretAccessKey")
        current = aws.get_region()
        s3_backups = vault.RaftSnapshotAgentConfig("s3Backups",
            interval_seconds=86400,
            retain=7,
            path_prefix="/path/in/bucket",
            storage_type="aws-s3",
            aws_s3_bucket="my-bucket",
            aws_s3_region=current.name,
            aws_access_key_id=aws_access_key_id,
            aws_secret_access_key=aws_secret_access_key,
            aws_s3_enable_kms=True)
        ```
        ### Azure BLOB

        ```python
        import pulumi
        import pulumi_vault as vault

        config = pulumi.Config()
        azure_account_name = config.require_object("azureAccountName")
        azure_account_key = config.require_object("azureAccountKey")
        azure_backups = vault.RaftSnapshotAgentConfig("azureBackups",
            interval_seconds=86400,
            retain=7,
            path_prefix="/",
            storage_type="azure-blob",
            azure_container_name="vault-blob",
            azure_account_name=azure_account_name,
            azure_account_key=azure_account_key)
        ```

        ## Import

        Raft Snapshot Agent Configurations can be imported using the `name`, e.g.

        ```sh
         $ pulumi import vault:index/raftSnapshotAgentConfig:RaftSnapshotAgentConfig local local
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aws_access_key_id: AWS access key ID.
        :param pulumi.Input[str] aws_s3_bucket: `<required>` - S3 bucket to write snapshots to.
        :param pulumi.Input[bool] aws_s3_disable_tls: Disable TLS for the S3 endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `aws_s3_endpoint`.
        :param pulumi.Input[bool] aws_s3_enable_kms: Use KMS to encrypt bucket contents.
        :param pulumi.Input[str] aws_s3_endpoint: AWS endpoint. This is typically only set when
               using a non-AWS S3 implementation like Minio.
        :param pulumi.Input[bool] aws_s3_force_path_style: Use the endpoint/bucket URL style
               instead of bucket.endpoint. May be needed when setting `aws_s3_endpoint`.
        :param pulumi.Input[str] aws_s3_kms_key: Use named KMS key, when `aws_s3_enable_kms = true`
        :param pulumi.Input[str] aws_s3_region: `<required>` - AWS region bucket is in.
        :param pulumi.Input[bool] aws_s3_server_side_encryption: Use AES256 to encrypt bucket contents.
        :param pulumi.Input[str] aws_secret_access_key: AWS secret access key.
        :param pulumi.Input[str] aws_session_token: AWS session token.
        :param pulumi.Input[str] azure_account_key: Azure account key.
        :param pulumi.Input[str] azure_account_name: Azure account name.
        :param pulumi.Input[str] azure_blob_environment: Azure blob environment.
        :param pulumi.Input[str] azure_container_name: `<required>` - Azure container name to write
               snapshots to.
        :param pulumi.Input[str] azure_endpoint: Azure blob storage endpoint. This is typically
               only set when using a non-Azure implementation like Azurite.
        :param pulumi.Input[str] file_prefix: Within the directory or bucket
               prefix given by `path_prefix`, the file or object name of snapshot files
               will start with this string.
        :param pulumi.Input[bool] google_disable_tls: Disable TLS for the GCS endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `google_endpoint`.
        :param pulumi.Input[str] google_endpoint: GCS endpoint. This is typically only set when
               using a non-Google GCS implementation like fake-gcs-server.
        :param pulumi.Input[str] google_gcs_bucket: `<required>` - GCS bucket to write snapshots to.
        :param pulumi.Input[str] google_service_account_key: Google service account key in JSON format. 
               The raw value looks like this:
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[int] interval_seconds: `<required>` - Time (in seconds) between snapshots.
        :param pulumi.Input[int] local_max_space: For `storage_type = local`, the maximum
               space, in bytes, to use for snapshots. Snapshot attempts will fail if there is not enough
               space left in this allowance.
        :param pulumi.Input[str] name: `<required>` – Name of the configuration to modify.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path_prefix: `<required>` - For `storage_type = "local"`, the directory to
               write the snapshots in. For cloud storage types, the bucket prefix to use.
               Types `azure-s3` and `google-gcs` require a trailing `/` (slash).
               Types `local` and `aws-s3` the trailing `/` is optional.
        :param pulumi.Input[int] retain: How many snapshots are to be kept; when writing a
               snapshot, if there are more snapshots already stored than this number, the
               oldest ones will be deleted.
        :param pulumi.Input[str] storage_type: `<required>` - One of "local", "azure-blob", "aws-s3",
               or "google-gcs". The remaining parameters described below are all specific to
               the selected `storage_type` and prefixed accordingly.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RaftSnapshotAgentConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage
        ### Local Storage
        ```python
        import pulumi
        import pulumi_vault as vault

        local_backups = vault.RaftSnapshotAgentConfig("localBackups",
            interval_seconds=86400,
            local_max_space=10000000,
            path_prefix="/opt/vault/snapshots/",
            retain=7,
            storage_type="local")
        ```
        ### AWS S3
        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_vault as vault

        config = pulumi.Config()
        aws_access_key_id = config.require_object("awsAccessKeyId")
        aws_secret_access_key = config.require_object("awsSecretAccessKey")
        current = aws.get_region()
        s3_backups = vault.RaftSnapshotAgentConfig("s3Backups",
            interval_seconds=86400,
            retain=7,
            path_prefix="/path/in/bucket",
            storage_type="aws-s3",
            aws_s3_bucket="my-bucket",
            aws_s3_region=current.name,
            aws_access_key_id=aws_access_key_id,
            aws_secret_access_key=aws_secret_access_key,
            aws_s3_enable_kms=True)
        ```
        ### Azure BLOB

        ```python
        import pulumi
        import pulumi_vault as vault

        config = pulumi.Config()
        azure_account_name = config.require_object("azureAccountName")
        azure_account_key = config.require_object("azureAccountKey")
        azure_backups = vault.RaftSnapshotAgentConfig("azureBackups",
            interval_seconds=86400,
            retain=7,
            path_prefix="/",
            storage_type="azure-blob",
            azure_container_name="vault-blob",
            azure_account_name=azure_account_name,
            azure_account_key=azure_account_key)
        ```

        ## Import

        Raft Snapshot Agent Configurations can be imported using the `name`, e.g.

        ```sh
         $ pulumi import vault:index/raftSnapshotAgentConfig:RaftSnapshotAgentConfig local local
        ```

        :param str resource_name: The name of the resource.
        :param RaftSnapshotAgentConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RaftSnapshotAgentConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_access_key_id: Optional[pulumi.Input[str]] = None,
                 aws_s3_bucket: Optional[pulumi.Input[str]] = None,
                 aws_s3_disable_tls: Optional[pulumi.Input[bool]] = None,
                 aws_s3_enable_kms: Optional[pulumi.Input[bool]] = None,
                 aws_s3_endpoint: Optional[pulumi.Input[str]] = None,
                 aws_s3_force_path_style: Optional[pulumi.Input[bool]] = None,
                 aws_s3_kms_key: Optional[pulumi.Input[str]] = None,
                 aws_s3_region: Optional[pulumi.Input[str]] = None,
                 aws_s3_server_side_encryption: Optional[pulumi.Input[bool]] = None,
                 aws_secret_access_key: Optional[pulumi.Input[str]] = None,
                 aws_session_token: Optional[pulumi.Input[str]] = None,
                 azure_account_key: Optional[pulumi.Input[str]] = None,
                 azure_account_name: Optional[pulumi.Input[str]] = None,
                 azure_blob_environment: Optional[pulumi.Input[str]] = None,
                 azure_container_name: Optional[pulumi.Input[str]] = None,
                 azure_endpoint: Optional[pulumi.Input[str]] = None,
                 file_prefix: Optional[pulumi.Input[str]] = None,
                 google_disable_tls: Optional[pulumi.Input[bool]] = None,
                 google_endpoint: Optional[pulumi.Input[str]] = None,
                 google_gcs_bucket: Optional[pulumi.Input[str]] = None,
                 google_service_account_key: Optional[pulumi.Input[str]] = None,
                 interval_seconds: Optional[pulumi.Input[int]] = None,
                 local_max_space: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path_prefix: Optional[pulumi.Input[str]] = None,
                 retain: Optional[pulumi.Input[int]] = None,
                 storage_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RaftSnapshotAgentConfigArgs.__new__(RaftSnapshotAgentConfigArgs)

            __props__.__dict__["aws_access_key_id"] = aws_access_key_id
            __props__.__dict__["aws_s3_bucket"] = aws_s3_bucket
            __props__.__dict__["aws_s3_disable_tls"] = aws_s3_disable_tls
            __props__.__dict__["aws_s3_enable_kms"] = aws_s3_enable_kms
            __props__.__dict__["aws_s3_endpoint"] = aws_s3_endpoint
            __props__.__dict__["aws_s3_force_path_style"] = aws_s3_force_path_style
            __props__.__dict__["aws_s3_kms_key"] = aws_s3_kms_key
            __props__.__dict__["aws_s3_region"] = aws_s3_region
            __props__.__dict__["aws_s3_server_side_encryption"] = aws_s3_server_side_encryption
            __props__.__dict__["aws_secret_access_key"] = aws_secret_access_key
            __props__.__dict__["aws_session_token"] = aws_session_token
            __props__.__dict__["azure_account_key"] = azure_account_key
            __props__.__dict__["azure_account_name"] = azure_account_name
            __props__.__dict__["azure_blob_environment"] = azure_blob_environment
            __props__.__dict__["azure_container_name"] = azure_container_name
            __props__.__dict__["azure_endpoint"] = azure_endpoint
            __props__.__dict__["file_prefix"] = file_prefix
            __props__.__dict__["google_disable_tls"] = google_disable_tls
            __props__.__dict__["google_endpoint"] = google_endpoint
            __props__.__dict__["google_gcs_bucket"] = google_gcs_bucket
            __props__.__dict__["google_service_account_key"] = google_service_account_key
            if interval_seconds is None and not opts.urn:
                raise TypeError("Missing required property 'interval_seconds'")
            __props__.__dict__["interval_seconds"] = interval_seconds
            __props__.__dict__["local_max_space"] = local_max_space
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            if path_prefix is None and not opts.urn:
                raise TypeError("Missing required property 'path_prefix'")
            __props__.__dict__["path_prefix"] = path_prefix
            __props__.__dict__["retain"] = retain
            if storage_type is None and not opts.urn:
                raise TypeError("Missing required property 'storage_type'")
            __props__.__dict__["storage_type"] = storage_type
        super(RaftSnapshotAgentConfig, __self__).__init__(
            'vault:index/raftSnapshotAgentConfig:RaftSnapshotAgentConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aws_access_key_id: Optional[pulumi.Input[str]] = None,
            aws_s3_bucket: Optional[pulumi.Input[str]] = None,
            aws_s3_disable_tls: Optional[pulumi.Input[bool]] = None,
            aws_s3_enable_kms: Optional[pulumi.Input[bool]] = None,
            aws_s3_endpoint: Optional[pulumi.Input[str]] = None,
            aws_s3_force_path_style: Optional[pulumi.Input[bool]] = None,
            aws_s3_kms_key: Optional[pulumi.Input[str]] = None,
            aws_s3_region: Optional[pulumi.Input[str]] = None,
            aws_s3_server_side_encryption: Optional[pulumi.Input[bool]] = None,
            aws_secret_access_key: Optional[pulumi.Input[str]] = None,
            aws_session_token: Optional[pulumi.Input[str]] = None,
            azure_account_key: Optional[pulumi.Input[str]] = None,
            azure_account_name: Optional[pulumi.Input[str]] = None,
            azure_blob_environment: Optional[pulumi.Input[str]] = None,
            azure_container_name: Optional[pulumi.Input[str]] = None,
            azure_endpoint: Optional[pulumi.Input[str]] = None,
            file_prefix: Optional[pulumi.Input[str]] = None,
            google_disable_tls: Optional[pulumi.Input[bool]] = None,
            google_endpoint: Optional[pulumi.Input[str]] = None,
            google_gcs_bucket: Optional[pulumi.Input[str]] = None,
            google_service_account_key: Optional[pulumi.Input[str]] = None,
            interval_seconds: Optional[pulumi.Input[int]] = None,
            local_max_space: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            path_prefix: Optional[pulumi.Input[str]] = None,
            retain: Optional[pulumi.Input[int]] = None,
            storage_type: Optional[pulumi.Input[str]] = None) -> 'RaftSnapshotAgentConfig':
        """
        Get an existing RaftSnapshotAgentConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aws_access_key_id: AWS access key ID.
        :param pulumi.Input[str] aws_s3_bucket: `<required>` - S3 bucket to write snapshots to.
        :param pulumi.Input[bool] aws_s3_disable_tls: Disable TLS for the S3 endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `aws_s3_endpoint`.
        :param pulumi.Input[bool] aws_s3_enable_kms: Use KMS to encrypt bucket contents.
        :param pulumi.Input[str] aws_s3_endpoint: AWS endpoint. This is typically only set when
               using a non-AWS S3 implementation like Minio.
        :param pulumi.Input[bool] aws_s3_force_path_style: Use the endpoint/bucket URL style
               instead of bucket.endpoint. May be needed when setting `aws_s3_endpoint`.
        :param pulumi.Input[str] aws_s3_kms_key: Use named KMS key, when `aws_s3_enable_kms = true`
        :param pulumi.Input[str] aws_s3_region: `<required>` - AWS region bucket is in.
        :param pulumi.Input[bool] aws_s3_server_side_encryption: Use AES256 to encrypt bucket contents.
        :param pulumi.Input[str] aws_secret_access_key: AWS secret access key.
        :param pulumi.Input[str] aws_session_token: AWS session token.
        :param pulumi.Input[str] azure_account_key: Azure account key.
        :param pulumi.Input[str] azure_account_name: Azure account name.
        :param pulumi.Input[str] azure_blob_environment: Azure blob environment.
        :param pulumi.Input[str] azure_container_name: `<required>` - Azure container name to write
               snapshots to.
        :param pulumi.Input[str] azure_endpoint: Azure blob storage endpoint. This is typically
               only set when using a non-Azure implementation like Azurite.
        :param pulumi.Input[str] file_prefix: Within the directory or bucket
               prefix given by `path_prefix`, the file or object name of snapshot files
               will start with this string.
        :param pulumi.Input[bool] google_disable_tls: Disable TLS for the GCS endpoint. This
               should only be used for testing purposes, typically in conjunction with
               `google_endpoint`.
        :param pulumi.Input[str] google_endpoint: GCS endpoint. This is typically only set when
               using a non-Google GCS implementation like fake-gcs-server.
        :param pulumi.Input[str] google_gcs_bucket: `<required>` - GCS bucket to write snapshots to.
        :param pulumi.Input[str] google_service_account_key: Google service account key in JSON format. 
               The raw value looks like this:
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[int] interval_seconds: `<required>` - Time (in seconds) between snapshots.
        :param pulumi.Input[int] local_max_space: For `storage_type = local`, the maximum
               space, in bytes, to use for snapshots. Snapshot attempts will fail if there is not enough
               space left in this allowance.
        :param pulumi.Input[str] name: `<required>` – Name of the configuration to modify.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path_prefix: `<required>` - For `storage_type = "local"`, the directory to
               write the snapshots in. For cloud storage types, the bucket prefix to use.
               Types `azure-s3` and `google-gcs` require a trailing `/` (slash).
               Types `local` and `aws-s3` the trailing `/` is optional.
        :param pulumi.Input[int] retain: How many snapshots are to be kept; when writing a
               snapshot, if there are more snapshots already stored than this number, the
               oldest ones will be deleted.
        :param pulumi.Input[str] storage_type: `<required>` - One of "local", "azure-blob", "aws-s3",
               or "google-gcs". The remaining parameters described below are all specific to
               the selected `storage_type` and prefixed accordingly.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RaftSnapshotAgentConfigState.__new__(_RaftSnapshotAgentConfigState)

        __props__.__dict__["aws_access_key_id"] = aws_access_key_id
        __props__.__dict__["aws_s3_bucket"] = aws_s3_bucket
        __props__.__dict__["aws_s3_disable_tls"] = aws_s3_disable_tls
        __props__.__dict__["aws_s3_enable_kms"] = aws_s3_enable_kms
        __props__.__dict__["aws_s3_endpoint"] = aws_s3_endpoint
        __props__.__dict__["aws_s3_force_path_style"] = aws_s3_force_path_style
        __props__.__dict__["aws_s3_kms_key"] = aws_s3_kms_key
        __props__.__dict__["aws_s3_region"] = aws_s3_region
        __props__.__dict__["aws_s3_server_side_encryption"] = aws_s3_server_side_encryption
        __props__.__dict__["aws_secret_access_key"] = aws_secret_access_key
        __props__.__dict__["aws_session_token"] = aws_session_token
        __props__.__dict__["azure_account_key"] = azure_account_key
        __props__.__dict__["azure_account_name"] = azure_account_name
        __props__.__dict__["azure_blob_environment"] = azure_blob_environment
        __props__.__dict__["azure_container_name"] = azure_container_name
        __props__.__dict__["azure_endpoint"] = azure_endpoint
        __props__.__dict__["file_prefix"] = file_prefix
        __props__.__dict__["google_disable_tls"] = google_disable_tls
        __props__.__dict__["google_endpoint"] = google_endpoint
        __props__.__dict__["google_gcs_bucket"] = google_gcs_bucket
        __props__.__dict__["google_service_account_key"] = google_service_account_key
        __props__.__dict__["interval_seconds"] = interval_seconds
        __props__.__dict__["local_max_space"] = local_max_space
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["path_prefix"] = path_prefix
        __props__.__dict__["retain"] = retain
        __props__.__dict__["storage_type"] = storage_type
        return RaftSnapshotAgentConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="awsAccessKeyId")
    def aws_access_key_id(self) -> pulumi.Output[Optional[str]]:
        """
        AWS access key ID.
        """
        return pulumi.get(self, "aws_access_key_id")

    @property
    @pulumi.getter(name="awsS3Bucket")
    def aws_s3_bucket(self) -> pulumi.Output[Optional[str]]:
        """
        `<required>` - S3 bucket to write snapshots to.
        """
        return pulumi.get(self, "aws_s3_bucket")

    @property
    @pulumi.getter(name="awsS3DisableTls")
    def aws_s3_disable_tls(self) -> pulumi.Output[Optional[bool]]:
        """
        Disable TLS for the S3 endpoint. This
        should only be used for testing purposes, typically in conjunction with
        `aws_s3_endpoint`.
        """
        return pulumi.get(self, "aws_s3_disable_tls")

    @property
    @pulumi.getter(name="awsS3EnableKms")
    def aws_s3_enable_kms(self) -> pulumi.Output[Optional[bool]]:
        """
        Use KMS to encrypt bucket contents.
        """
        return pulumi.get(self, "aws_s3_enable_kms")

    @property
    @pulumi.getter(name="awsS3Endpoint")
    def aws_s3_endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        AWS endpoint. This is typically only set when
        using a non-AWS S3 implementation like Minio.
        """
        return pulumi.get(self, "aws_s3_endpoint")

    @property
    @pulumi.getter(name="awsS3ForcePathStyle")
    def aws_s3_force_path_style(self) -> pulumi.Output[Optional[bool]]:
        """
        Use the endpoint/bucket URL style
        instead of bucket.endpoint. May be needed when setting `aws_s3_endpoint`.
        """
        return pulumi.get(self, "aws_s3_force_path_style")

    @property
    @pulumi.getter(name="awsS3KmsKey")
    def aws_s3_kms_key(self) -> pulumi.Output[Optional[str]]:
        """
        Use named KMS key, when `aws_s3_enable_kms = true`
        """
        return pulumi.get(self, "aws_s3_kms_key")

    @property
    @pulumi.getter(name="awsS3Region")
    def aws_s3_region(self) -> pulumi.Output[Optional[str]]:
        """
        `<required>` - AWS region bucket is in.
        """
        return pulumi.get(self, "aws_s3_region")

    @property
    @pulumi.getter(name="awsS3ServerSideEncryption")
    def aws_s3_server_side_encryption(self) -> pulumi.Output[Optional[bool]]:
        """
        Use AES256 to encrypt bucket contents.
        """
        return pulumi.get(self, "aws_s3_server_side_encryption")

    @property
    @pulumi.getter(name="awsSecretAccessKey")
    def aws_secret_access_key(self) -> pulumi.Output[Optional[str]]:
        """
        AWS secret access key.
        """
        return pulumi.get(self, "aws_secret_access_key")

    @property
    @pulumi.getter(name="awsSessionToken")
    def aws_session_token(self) -> pulumi.Output[Optional[str]]:
        """
        AWS session token.
        """
        return pulumi.get(self, "aws_session_token")

    @property
    @pulumi.getter(name="azureAccountKey")
    def azure_account_key(self) -> pulumi.Output[Optional[str]]:
        """
        Azure account key.
        """
        return pulumi.get(self, "azure_account_key")

    @property
    @pulumi.getter(name="azureAccountName")
    def azure_account_name(self) -> pulumi.Output[Optional[str]]:
        """
        Azure account name.
        """
        return pulumi.get(self, "azure_account_name")

    @property
    @pulumi.getter(name="azureBlobEnvironment")
    def azure_blob_environment(self) -> pulumi.Output[Optional[str]]:
        """
        Azure blob environment.
        """
        return pulumi.get(self, "azure_blob_environment")

    @property
    @pulumi.getter(name="azureContainerName")
    def azure_container_name(self) -> pulumi.Output[Optional[str]]:
        """
        `<required>` - Azure container name to write
        snapshots to.
        """
        return pulumi.get(self, "azure_container_name")

    @property
    @pulumi.getter(name="azureEndpoint")
    def azure_endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        Azure blob storage endpoint. This is typically
        only set when using a non-Azure implementation like Azurite.
        """
        return pulumi.get(self, "azure_endpoint")

    @property
    @pulumi.getter(name="filePrefix")
    def file_prefix(self) -> pulumi.Output[Optional[str]]:
        """
        Within the directory or bucket
        prefix given by `path_prefix`, the file or object name of snapshot files
        will start with this string.
        """
        return pulumi.get(self, "file_prefix")

    @property
    @pulumi.getter(name="googleDisableTls")
    def google_disable_tls(self) -> pulumi.Output[Optional[bool]]:
        """
        Disable TLS for the GCS endpoint. This
        should only be used for testing purposes, typically in conjunction with
        `google_endpoint`.
        """
        return pulumi.get(self, "google_disable_tls")

    @property
    @pulumi.getter(name="googleEndpoint")
    def google_endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        GCS endpoint. This is typically only set when
        using a non-Google GCS implementation like fake-gcs-server.
        """
        return pulumi.get(self, "google_endpoint")

    @property
    @pulumi.getter(name="googleGcsBucket")
    def google_gcs_bucket(self) -> pulumi.Output[Optional[str]]:
        """
        `<required>` - GCS bucket to write snapshots to.
        """
        return pulumi.get(self, "google_gcs_bucket")

    @property
    @pulumi.getter(name="googleServiceAccountKey")
    def google_service_account_key(self) -> pulumi.Output[Optional[str]]:
        """
        Google service account key in JSON format. 
        The raw value looks like this:

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "google_service_account_key")

    @property
    @pulumi.getter(name="intervalSeconds")
    def interval_seconds(self) -> pulumi.Output[int]:
        """
        `<required>` - Time (in seconds) between snapshots.
        """
        return pulumi.get(self, "interval_seconds")

    @property
    @pulumi.getter(name="localMaxSpace")
    def local_max_space(self) -> pulumi.Output[Optional[int]]:
        """
        For `storage_type = local`, the maximum
        space, in bytes, to use for snapshots. Snapshot attempts will fail if there is not enough
        space left in this allowance.
        """
        return pulumi.get(self, "local_max_space")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        `<required>` – Name of the configuration to modify.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> pulumi.Output[str]:
        """
        `<required>` - For `storage_type = "local"`, the directory to
        write the snapshots in. For cloud storage types, the bucket prefix to use.
        Types `azure-s3` and `google-gcs` require a trailing `/` (slash).
        Types `local` and `aws-s3` the trailing `/` is optional.
        """
        return pulumi.get(self, "path_prefix")

    @property
    @pulumi.getter
    def retain(self) -> pulumi.Output[Optional[int]]:
        """
        How many snapshots are to be kept; when writing a
        snapshot, if there are more snapshots already stored than this number, the
        oldest ones will be deleted.
        """
        return pulumi.get(self, "retain")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Output[str]:
        """
        `<required>` - One of "local", "azure-blob", "aws-s3",
        or "google-gcs". The remaining parameters described below are all specific to
        the selected `storage_type` and prefixed accordingly.
        """
        return pulumi.get(self, "storage_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['QuotaRateLimitArgs', 'QuotaRateLimit']

@pulumi.input_type
class QuotaRateLimitArgs:
    def __init__(__self__, *,
                 rate: pulumi.Input[float],
                 block_interval: Optional[pulumi.Input[int]] = None,
                 interval: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a QuotaRateLimit resource.
        :param pulumi.Input[float] rate: The maximum number of requests at any given second to be allowed by the quota
               rule. The `rate` must be positive.
        :param pulumi.Input[int] block_interval: If set, when a client reaches a rate limit threshold, the client will
               be prohibited from any further requests until after the 'block_interval' in seconds has elapsed.
        :param pulumi.Input[int] interval: The duration in seconds to enforce rate limiting for.
        :param pulumi.Input[str] name: Name of the rate limit quota
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured namespace.
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: Path of the mount or namespace to apply the quota. A blank path configures a
               global rate limit quota. For example `namespace1/` adds a quota to a full namespace,
               `namespace1/auth/userpass` adds a `quota` to `userpass` in `namespace1`.
               Updating this field on an existing quota can have "moving" effects. For example, updating
               `auth/userpass` to `namespace1/auth/userpass` moves this quota from being a global mount quota to
               a namespace specific mount quota. **Note, namespaces are supported in Enterprise only.**
        :param pulumi.Input[str] role: If set on a quota where `path` is set to an auth mount with a concept of roles (such as /auth/approle/), this will make the quota restrict login requests to that mount that are made with the specified role.
        """
        pulumi.set(__self__, "rate", rate)
        if block_interval is not None:
            pulumi.set(__self__, "block_interval", block_interval)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter
    def rate(self) -> pulumi.Input[float]:
        """
        The maximum number of requests at any given second to be allowed by the quota
        rule. The `rate` must be positive.
        """
        return pulumi.get(self, "rate")

    @rate.setter
    def rate(self, value: pulumi.Input[float]):
        pulumi.set(self, "rate", value)

    @property
    @pulumi.getter(name="blockInterval")
    def block_interval(self) -> Optional[pulumi.Input[int]]:
        """
        If set, when a client reaches a rate limit threshold, the client will
        be prohibited from any further requests until after the 'block_interval' in seconds has elapsed.
        """
        return pulumi.get(self, "block_interval")

    @block_interval.setter
    def block_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "block_interval", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[int]]:
        """
        The duration in seconds to enforce rate limiting for.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the rate limit quota
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured namespace.
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        Path of the mount or namespace to apply the quota. A blank path configures a
        global rate limit quota. For example `namespace1/` adds a quota to a full namespace,
        `namespace1/auth/userpass` adds a `quota` to `userpass` in `namespace1`.
        Updating this field on an existing quota can have "moving" effects. For example, updating
        `auth/userpass` to `namespace1/auth/userpass` moves this quota from being a global mount quota to
        a namespace specific mount quota. **Note, namespaces are supported in Enterprise only.**
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        If set on a quota where `path` is set to an auth mount with a concept of roles (such as /auth/approle/), this will make the quota restrict login requests to that mount that are made with the specified role.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)


@pulumi.input_type
class _QuotaRateLimitState:
    def __init__(__self__, *,
                 block_interval: Optional[pulumi.Input[int]] = None,
                 interval: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 rate: Optional[pulumi.Input[float]] = None,
                 role: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering QuotaRateLimit resources.
        :param pulumi.Input[int] block_interval: If set, when a client reaches a rate limit threshold, the client will
               be prohibited from any further requests until after the 'block_interval' in seconds has elapsed.
        :param pulumi.Input[int] interval: The duration in seconds to enforce rate limiting for.
        :param pulumi.Input[str] name: Name of the rate limit quota
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured namespace.
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: Path of the mount or namespace to apply the quota. A blank path configures a
               global rate limit quota. For example `namespace1/` adds a quota to a full namespace,
               `namespace1/auth/userpass` adds a `quota` to `userpass` in `namespace1`.
               Updating this field on an existing quota can have "moving" effects. For example, updating
               `auth/userpass` to `namespace1/auth/userpass` moves this quota from being a global mount quota to
               a namespace specific mount quota. **Note, namespaces are supported in Enterprise only.**
        :param pulumi.Input[float] rate: The maximum number of requests at any given second to be allowed by the quota
               rule. The `rate` must be positive.
        :param pulumi.Input[str] role: If set on a quota where `path` is set to an auth mount with a concept of roles (such as /auth/approle/), this will make the quota restrict login requests to that mount that are made with the specified role.
        """
        if block_interval is not None:
            pulumi.set(__self__, "block_interval", block_interval)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if rate is not None:
            pulumi.set(__self__, "rate", rate)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter(name="blockInterval")
    def block_interval(self) -> Optional[pulumi.Input[int]]:
        """
        If set, when a client reaches a rate limit threshold, the client will
        be prohibited from any further requests until after the 'block_interval' in seconds has elapsed.
        """
        return pulumi.get(self, "block_interval")

    @block_interval.setter
    def block_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "block_interval", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[int]]:
        """
        The duration in seconds to enforce rate limiting for.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the rate limit quota
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured namespace.
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        Path of the mount or namespace to apply the quota. A blank path configures a
        global rate limit quota. For example `namespace1/` adds a quota to a full namespace,
        `namespace1/auth/userpass` adds a `quota` to `userpass` in `namespace1`.
        Updating this field on an existing quota can have "moving" effects. For example, updating
        `auth/userpass` to `namespace1/auth/userpass` moves this quota from being a global mount quota to
        a namespace specific mount quota. **Note, namespaces are supported in Enterprise only.**
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def rate(self) -> Optional[pulumi.Input[float]]:
        """
        The maximum number of requests at any given second to be allowed by the quota
        rule. The `rate` must be positive.
        """
        return pulumi.get(self, "rate")

    @rate.setter
    def rate(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "rate", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        If set on a quota where `path` is set to an auth mount with a concept of roles (such as /auth/approle/), this will make the quota restrict login requests to that mount that are made with the specified role.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)


class QuotaRateLimit(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block_interval: Optional[pulumi.Input[int]] = None,
                 interval: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 rate: Optional[pulumi.Input[float]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manage rate limit quotas which enforce API rate limiting using a token bucket algorithm.
        A rate limit quota can be created at the root level or defined on a namespace or mount by
        specifying a path when creating the quota.

        See [Vault's Documentation](https://www.vaultproject.io/docs/concepts/resource-quotas) for more
        information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        global_ = vault.QuotaRateLimit("global",
            path="",
            rate=100)
        ```

        ## Import

        Rate limit quotas can be imported using their names

        ```sh
         $ pulumi import vault:index/quotaRateLimit:QuotaRateLimit global global
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] block_interval: If set, when a client reaches a rate limit threshold, the client will
               be prohibited from any further requests until after the 'block_interval' in seconds has elapsed.
        :param pulumi.Input[int] interval: The duration in seconds to enforce rate limiting for.
        :param pulumi.Input[str] name: Name of the rate limit quota
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured namespace.
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: Path of the mount or namespace to apply the quota. A blank path configures a
               global rate limit quota. For example `namespace1/` adds a quota to a full namespace,
               `namespace1/auth/userpass` adds a `quota` to `userpass` in `namespace1`.
               Updating this field on an existing quota can have "moving" effects. For example, updating
               `auth/userpass` to `namespace1/auth/userpass` moves this quota from being a global mount quota to
               a namespace specific mount quota. **Note, namespaces are supported in Enterprise only.**
        :param pulumi.Input[float] rate: The maximum number of requests at any given second to be allowed by the quota
               rule. The `rate` must be positive.
        :param pulumi.Input[str] role: If set on a quota where `path` is set to an auth mount with a concept of roles (such as /auth/approle/), this will make the quota restrict login requests to that mount that are made with the specified role.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuotaRateLimitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage rate limit quotas which enforce API rate limiting using a token bucket algorithm.
        A rate limit quota can be created at the root level or defined on a namespace or mount by
        specifying a path when creating the quota.

        See [Vault's Documentation](https://www.vaultproject.io/docs/concepts/resource-quotas) for more
        information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        global_ = vault.QuotaRateLimit("global",
            path="",
            rate=100)
        ```

        ## Import

        Rate limit quotas can be imported using their names

        ```sh
         $ pulumi import vault:index/quotaRateLimit:QuotaRateLimit global global
        ```

        :param str resource_name: The name of the resource.
        :param QuotaRateLimitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuotaRateLimitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block_interval: Optional[pulumi.Input[int]] = None,
                 interval: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 rate: Optional[pulumi.Input[float]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuotaRateLimitArgs.__new__(QuotaRateLimitArgs)

            __props__.__dict__["block_interval"] = block_interval
            __props__.__dict__["interval"] = interval
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["path"] = path
            if rate is None and not opts.urn:
                raise TypeError("Missing required property 'rate'")
            __props__.__dict__["rate"] = rate
            __props__.__dict__["role"] = role
        super(QuotaRateLimit, __self__).__init__(
            'vault:index/quotaRateLimit:QuotaRateLimit',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            block_interval: Optional[pulumi.Input[int]] = None,
            interval: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            path: Optional[pulumi.Input[str]] = None,
            rate: Optional[pulumi.Input[float]] = None,
            role: Optional[pulumi.Input[str]] = None) -> 'QuotaRateLimit':
        """
        Get an existing QuotaRateLimit resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] block_interval: If set, when a client reaches a rate limit threshold, the client will
               be prohibited from any further requests until after the 'block_interval' in seconds has elapsed.
        :param pulumi.Input[int] interval: The duration in seconds to enforce rate limiting for.
        :param pulumi.Input[str] name: Name of the rate limit quota
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured namespace.
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] path: Path of the mount or namespace to apply the quota. A blank path configures a
               global rate limit quota. For example `namespace1/` adds a quota to a full namespace,
               `namespace1/auth/userpass` adds a `quota` to `userpass` in `namespace1`.
               Updating this field on an existing quota can have "moving" effects. For example, updating
               `auth/userpass` to `namespace1/auth/userpass` moves this quota from being a global mount quota to
               a namespace specific mount quota. **Note, namespaces are supported in Enterprise only.**
        :param pulumi.Input[float] rate: The maximum number of requests at any given second to be allowed by the quota
               rule. The `rate` must be positive.
        :param pulumi.Input[str] role: If set on a quota where `path` is set to an auth mount with a concept of roles (such as /auth/approle/), this will make the quota restrict login requests to that mount that are made with the specified role.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuotaRateLimitState.__new__(_QuotaRateLimitState)

        __props__.__dict__["block_interval"] = block_interval
        __props__.__dict__["interval"] = interval
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["path"] = path
        __props__.__dict__["rate"] = rate
        __props__.__dict__["role"] = role
        return QuotaRateLimit(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="blockInterval")
    def block_interval(self) -> pulumi.Output[Optional[int]]:
        """
        If set, when a client reaches a rate limit threshold, the client will
        be prohibited from any further requests until after the 'block_interval' in seconds has elapsed.
        """
        return pulumi.get(self, "block_interval")

    @property
    @pulumi.getter
    def interval(self) -> pulumi.Output[int]:
        """
        The duration in seconds to enforce rate limiting for.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the rate limit quota
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured namespace.
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[Optional[str]]:
        """
        Path of the mount or namespace to apply the quota. A blank path configures a
        global rate limit quota. For example `namespace1/` adds a quota to a full namespace,
        `namespace1/auth/userpass` adds a `quota` to `userpass` in `namespace1`.
        Updating this field on an existing quota can have "moving" effects. For example, updating
        `auth/userpass` to `namespace1/auth/userpass` moves this quota from being a global mount quota to
        a namespace specific mount quota. **Note, namespaces are supported in Enterprise only.**
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def rate(self) -> pulumi.Output[float]:
        """
        The maximum number of requests at any given second to be allowed by the quota
        rule. The `rate` must be positive.
        """
        return pulumi.get(self, "rate")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[Optional[str]]:
        """
        If set on a quota where `path` is set to an auth mount with a concept of roles (such as /auth/approle/), this will make the quota restrict login requests to that mount that are made with the specified role.
        """
        return pulumi.get(self, "role")

